@@ -168,23 +168,22 @@ class NumberVisDescriptor(AbstractVisDescriptor):
         presenter(value_non_synth, stream)
 
 
-CharPresentationInfo = Tuple[int, str, str]
-
-
 class CharVisDescriptor(AbstractVisDescriptor):
-    char_types = {"char": (1, "", '__locale__'),
-                  "unsigned char": (1, "", '__locale__'),
-                  "signed char": (1, "", '__locale__'),
-                  "wchar_t": (2, "L", 'utf-16'),
-                  "char8_t": (1, "", 'utf-8'),
-                  "char16_t": (2, "u", 'utf-16'),
-                  "char32_t": (4, "U", 'utf-32')}
+    char_types = {
+        "char": CharPresentationInfo(1, lldb.eBasicTypeChar),
+        "unsigned char": CharPresentationInfo(1, lldb.eBasicTypeUnsignedChar),
+        "signed char": CharPresentationInfo(1, lldb.eBasicTypeSignedChar),
+        "wchar_t": CharPresentationInfo(2, lldb.eBasicTypeWChar, 'utf-16', "L"),
+        "char8_t": CharPresentationInfo(1, lldb.eBasicTypeUnsignedChar, 'utf-8'),
+        "char16_t": CharPresentationInfo(2, lldb.eBasicTypeChar16, 'utf-16', "u"),
+        "char32_t": CharPresentationInfo(4, lldb.eBasicTypeChar32, 'utf-32', "U")
+    }
 
     def __init__(self, char_presentation_info: CharPresentationInfo):
         self.char_presentation_info = char_presentation_info
 
     def output_summary(self, value_non_synth: lldb.SBValue, stream: Stream):
-        char_size, prefix, enc = self.char_presentation_info
+        enc = self.char_presentation_info.encoding
         if enc == '__locale__':
             enc = get_locale()
         err = SBError()
@@ -211,7 +210,8 @@ class CharVisDescriptor(AbstractVisDescriptor):
             stream.output_number(str(code))
         stream.output(" ")
         # Unlike Visual Studio's behavior we present wchar_t as L'x' (for consistency with wide strings L"xxx")
-        stream.output_string(prefix + "'" + escape_char(ordinal, char_size, enc) + "'")
+        escaped_char = escape_char(ordinal, self.char_presentation_info.char_size, enc)
+        stream.output_string(f"{self.char_presentation_info.literal_prefix}'{escaped_char}'")
 
 
 def _cast_value_to_array(value_non_synth: lldb.SBValue, is_array: bool, fmt: int, array_size: int):
@@ -224,6 +224,14 @@ def _cast_value_to_array(value_non_synth: lldb.SBValue, is_array: bool, fmt: int
 
 
 class CharArrayOrPointerVisDescriptor(AbstractVisDescriptor):
+    _basic_types_convertable_to_pointer = {
+        eBasicTypeInt, eBasicTypeUnsignedInt, eBasicTypeLong, eBasicTypeUnsignedLong, eBasicTypeLongLong, eBasicTypeUnsignedLongLong
+    }
+
+    @classmethod
+    def can_type_be_used_as_char_pointer(cls, value_type: lldb.SBType):
+        return value_type.GetBasicType() in cls._basic_types_convertable_to_pointer
+
     def __init__(self, presentation_info: CharPresentationInfo, is_array: bool, array_size=None, formatted_array=False):
         self.presentation_info = presentation_info
         self.is_array = is_array
@@ -231,7 +239,6 @@ class CharArrayOrPointerVisDescriptor(AbstractVisDescriptor):
         self.formatted_array = formatted_array
 
     def output_summary(self, value_non_synth: lldb.SBValue, stream: Stream):
-        char_size, prefix, enc = self.presentation_info
         fmt = value_non_synth.GetFormat()
 
         if fmt & eFormatAsArray != 0:
@@ -247,17 +254,18 @@ class CharArrayOrPointerVisDescriptor(AbstractVisDescriptor):
 
         if not suppress_address:
             stream.output_address(address)
-            stream.output(" ")
+            stream.output_comment(" ") # print space as a comment to skip it during text extraction (copy value)
 
         zero_required = not self.formatted_array
 
         err = lldb.SBError()
-        max_size = self.array_size * char_size if self.array_size is not None else None
-        content, zero_found = extract_string(value_non_synth.GetProcess(), address, char_size, max_size, err)
+        max_size = self.array_size * self.presentation_info.char_size if self.array_size is not None else None
+        content, zero_found = extract_string(value_non_synth.GetProcess(), address, self.presentation_info.char_size, max_size, err)
         if err.Fail():
             stream.output('<error>')
             return
 
+        enc = self.presentation_info.encoding
         if enc == '__locale__':
             enc = get_locale()
         s = escape_bytes(content, enc)
@@ -266,7 +274,7 @@ class CharArrayOrPointerVisDescriptor(AbstractVisDescriptor):
         result = StringIO()
 
         if quote:
-            result.write(prefix)
+            result.write(self.presentation_info.literal_prefix)
             result.write('"')
         result.write(s)
         if zero_found or not zero_required:
@@ -290,6 +298,8 @@ class CharArrayOrPointerVisDescriptor(AbstractVisDescriptor):
         # TODO: check fmt_array_size
 
         provider = CharArrayOrPointerVisDescriptor(self.presentation_info, True, fmt_array_size, True)
+        if self.can_type_be_used_as_char_pointer(value_non_synth.GetType()):
+            value_non_synth = ItemExpression.cast_value_to_basic_type_pointer(value_non_synth, self.presentation_info.lldb_basic_type)
         new_val = _cast_value_to_array(value_non_synth, self.is_array, fmt, fmt_array_size)
         return provider, new_val
 
